import React, { Component } from 'react';
import { addClass } from '../Utils';
import Input from '../Input';
import Select from '../Select';
import config from './config';


class Calendar extends Component {
  constructor(props) {
    super(props);
    this.state = {
      show: false
    }
    const now = props.value ? new Date(props.value) : new Date();
    this.state.year = now.getFullYear();
    this.state.month = now.getMonth() + 1;
    this.state.day = now.getDate();
    this.state.dayList = this.getDayList();
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
  }

  getDayList() {
    this.state.dayList = [];
    const { year, month } = this.state;
    const nowMonth = new Date(year + '-' + month + '-1');
    const prevDate = new Date(year + '-' + month - 1 >= 0 ? month - 1 : 11 + '-1');
    const prevMonth = prevDate.getMonth() + 1;
    let week = nowMonth.getDay();
    week = week == 0 ? 7 : week;
    week = week - 1;
    let prevMax = 30;
    if (prevMonth == 1 || prevMonth == 3 || prevMonth == 5 || prevMonth == 7 || prevMonth == 8 || prevMonth == 10 || prevMonth == 12) {
      prevMax = 31;
    }
    if (prevMonth == 2) {
      if (((year % 4) == 0) && ((year % 100) != 0) || ((year % 400) == 0)) {
        prevMax = 29;
      } else {
        prevMax = 28;
      }
    }
    for (let i = 1; i <= week; i += 1) {
      this.state.dayList.push({
        value: prevMax - week + i,
        type: false
      })
    }

    let max = 30;
    if (month == 1 || month == 3 || month == 5 || month == 7 || month == 8 || month == 10 || month == 12) {
      max = 31;
    }
    if (month == 2) {
      if (((year % 4) == 0) && ((year % 100) != 0) || ((year % 400) == 0)) {
        max = 29;
      } else {
        max = 28;
      }
    }
    for (let i = 1; i <= max; i += 1) {
      this.state.dayList.push({
        value: i,
        type: true
      });
    }
    const len = 42 - this.state.dayList.length;
    for (let i = 1; i <= len; i += 1) {
      this.state.dayList.push({
        value: i,
        type: false
      });
    }
    return this.state.dayList;
  }

  show() {
    this.setState({ show: true })
  }
  Mnext() {
    const month = Number(this.state.month) + 1 > 12 ? 1 : Number(this.state.month) + 1;
    this.state.month = month;
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
    this.setState({ month, dayList: this.getDayList(), value: this.state.value });
  }
  Mprev() {
    const month = this.state.month - 1 < 1 ? 12 : this.state.month - 1;
    this.state.month = month;
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
    this.setState({ month, dayList: this.getDayList(), value: this.state.value });
  }
  Ynext() {
    const year = Number(this.state.year) + 1;
    this.state.year = year;
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
    this.setState({ year, dayList: this.getDayList(), value: this.state.value });
  }
  Yprev() {
    const year = this.state.year - 1;
    this.state.year = year;
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
    this.setState({ year, dayList: this.getDayList(), value: this.state.value });
  }
  selectDay(value, e) {
    e.stopPropagation();
    e.preventDefault();
    e.nativeEvent.stopImmediatePropagation();
    this.state.day = value;
    this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
    this.setState({ show: false, value: this.state.value });
    this.returnDate();
  }
  returnDate() {
    const { year, month, day } = this.state;
    const nowMonth = new Date(year + '-' + month + '-' + day);
    this.props.onChange && this.props.onChange(nowMonth.getTime());
  }
  changeMonth(value) {
    if (value < 15) {
      this.Mnext();
    } else {
      this.Mprev();
    }
  }
  render() {
    const { className, style, placeholder, showName, fileName } = this.props;
    const { value, show, year, month, dayList, day } = this.state;
    const content = [];
    let i = -1;
    dayList.forEach((item, idx) => {
      if (idx % 7 === 0) {
        i += 1;
        content[i] = [];
      }
      content[i].push(item);
    })
    return (
      <div className={addClass('calendar-wrap')} onClick={this.show.bind(this)}>
        <Input
          placeholder={placeholder}
          fileName={fileName}
          showName={showName}
          value={value}
          disabled
        />
        <div className="calendar-wrap" style={{ display: show ? 'block' : 'none' }}>
          <div className="top-line">
            <div className="left select" onClick={this.Yprev.bind(this)}>&lt;&lt;</div>
            <div className="prev select" onClick={this.Mprev.bind(this)}>&lt;</div>
            <div className="month select">
              <Select
                showName={false}
                allowClear={false}
                className='calendar-year-wrap'
                options={config.YEARLIST}
                value={year}
                onChange={(value) => {
                  this.state.year = value.key;
                  this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
                  this.setState({ dayList: this.getDayList(), value: this.state.value })
                }}
              />
            </div>
            <div className="year select">
              <Select
                showName={false}
                allowClear={false}
                className='calendar-year-wrap'
                options={config.MONTHLIST}
                value={month}
                onChange={(value) => {
                  this.state.month = value.key;
                  this.state.value = `${this.state.year}/${this.state.month < 10 ? '0' + this.state.month : this.state.month}/${this.state.day < 10 ? '0' + this.state.day : this.state.day}`;
                  this.setState({ dayList: this.getDayList(), value: this.state.value })
                }}
              />
            </div>
            <div className="next select" onClick={this.Mnext.bind(this)}>&gt;</div>
            <div className="right select" onClick={this.Ynext.bind(this)}>&gt;&gt;</div>
          </div>
          <div className="week-wrap">
            <div>一</div>
            <div>二</div>
            <div>三</div>
            <div>四</div>
            <div>五</div>
            <div style={{ color: '#24d0fb' }}>六</div>
            <div style={{ color: '#24d0fb' }}>日</div>
          </div>
          <div className="data-item-wrap">
            {
              content.map((item, idx) => (
                <div className="data-item" key={idx}>
                  {
                    item.map((item, idx) => (
                      <div
                        style={idx > 4 ? { color: '#24d0fb' } : {}}
                        className={item.type ? 'now-month' : 'no-now-month'}
                        style={day === item.value && item.type ? { background: '#97e8ff', borderRadius: '3px' } : {}}
                        onClick={
                          item.type ?
                            this.selectDay.bind(this, item.value) : this.changeMonth.bind(this, item.value)
                        }
                      >{item.value}</div>
                    ))
                  }
                </div>
              ))
            }
          </div>
        </div>
      </div>
    );
  }
}

Calendar.propTypes = {
  value: React.PropTypes.string,
  className: React.PropTypes.string,
  placeholder: React.PropTypes.string,
  fileName: React.PropTypes.string,
  showName: React.PropTypes.bool,
  onChange: React.PropTypes.func,
  onblur: React.PropTypes.func,
  onFocus: React.PropTypes.func,
  onClick: React.PropTypes.func,
};
Calendar.defaultProps = {
  value: '',
  fileName: '年月日',
  showName: false,
  className: '',
  placeholder: '请选择年月日',
  onChange: () => { },
  onblur: () => { },
  onFocus: () => { },
  onClick: () => { },
};
export default Calendar;