import React, { PropTypes, Component } from 'react';

import CheckBoxItem from './CheckBoxItem.jsx';

require('./style.less');

Array.prototype.contain = function (val) { // 扩展数组
  for (let i = 0; i < this.length; i += 1) {
    if (this[i] == val) {
      return true;
    }
  }
  return false;
};

Array.prototype.remove = function (dx) {
  if (!dx || !this.length) {
    return [];
  }

  for (let i = 0; i < this.length; i += 1) {
    if (this[i] == dx) {
      this.splice(i, 1);
      return this;
    }
  }
  return this;
};

export default class Checkbox extends Component {

  constructor(props) {
    super(props);
    this.state = {
      value: props.value || []
    };
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.value !== this.state.value) {
      this.setState({ value: nextProps.value });
    }
  }

  onSelect(key) {
    const { value } = this.state;
    if (value && value.contain(key)) {
      value.remove(key);
    } else {
      value.push(key);
    }
    this.setState({ value });
    this.props.onChange(value);
  }

  getValue() {
    return this.state.value;
  }

  render() {
    const { options, disabled, className, lineHeight } = this.props;
    const { value } = this.state;
    return (
      <div className={`cg-checkbox ${className}`}>
        {
          Object.keys(options).map((key, idx) => {
            return (<CheckBoxItem
              className={'checkbox-item'}
              style={{ height: lineHeight }}
              key={idx}
              checked={value && value.contain(key)}
              onChange={this.onSelect.bind(this, key)}
              text={options[key]}
              disabled={disabled}
            />);
          })
        }
      </div>
    );
  }
}
Checkbox.propTypes = {
  options: PropTypes.objectOf(PropTypes.any),
  value: PropTypes.string,
  onChange: PropTypes.func,
  disabled: PropTypes.bool,
  name: PropTypes.string,
  className: PropTypes.string,
  lineHeight: PropTypes.string
}

Checkbox.defaultProps = {
  options: {},
  value: null,
  onChange() { },
  disabled: false,
  className: '',
  lineHeight: '30px'
};
