import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import { addClass } from '../Utils';
import Modal from '../Modal';

const info = require('../../images/info.png');
const success = require('../../images/success.png');
const error = require('../../images/error.png');
const warn = require('../../images/warn.png');

class Dialog extends Component {
  constructor(props) {
    super(props);
    this.state = {
      show: true
    }
  }

  onClick(bool) {
    const { submit, cancel } = this.props;
    this.setState({ show: false });
    if (bool) {
      submit && submit();
    } else {
      cancel && cancel();
    }
  }


  render() {
    const { submit, cancel, type, title } = this.props;
    let img = info;
    let alt = '提示';
    if (type === 'success') {
      img = success;
      alt = '成功';
    } else if (type === 'error') {
      img = error;
      alt = '失败';
    } else if (type === 'warn') {
      img = warn;
      alt = '警告';
    }
    const head = <div className="dialog-title">
      <img src={img} alt={alt} />
      <h3>{title || alt}</h3>
    </div>;
    const foot = <div className="dialog-footer">
      {
        submit ? <button onClick={this.onClick.bind(this, true)}>确&nbsp;&nbsp;定</button> : null
      }
      &nbsp;&nbsp;
      {
        cancel ? <button onClick={this.onClick.bind(this, false)}>取&nbsp;&nbsp;消</button> : null
      }
    </div>;
    return (
      <Modal
        show={this.state.show}
        width={'300px'}
        height={'170px'}
      >
        <div className={addClass('dialog-wrap')}>
          {head}
          <div className="dialog-content">{this.props.content || alt}</div>
          {foot}
        </div>
      </Modal>
    );
  }
}

Dialog.show = (props) => {
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  ReactDOM.render(<Dialog {...props} />, div);
}

Dialog.success = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'success';
  ReactDOM.render(<Dialog {...props} />, div);
}

Dialog.error = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'error';
  ReactDOM.render(<Dialog {...props} />, div);
}
Dialog.alert = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'info';
  ReactDOM.render(<Dialog {...props} />, div);
}
Dialog.confirm = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'info';
  props.cancel = props.cancel || function() { console.log('取消')};
  ReactDOM.render(<Dialog {...props} />, div);
}
Dialog.warn = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'warn'
  ReactDOM.render(<Dialog {...props} />, div);
}

Dialog.info = (props) => {
  props = props || {};
  const div = document.createElement('div');
  div.className = 'ying-view-ui';
  document.body.appendChild(div);
  props.type = 'info'
  ReactDOM.render(<Dialog {...props} />, div);
}


Dialog.propTypes = {
  type: React.PropTypes.string,
  title: React.PropTypes.string,
  content: React.PropTypes.string,
  submit: React.PropTypes.func,
  cancel: React.PropTypes.func

};
Dialog.defaultProps = {
  // type: 'success', // error  info warn
  // title: '提示',
  // content: '操作成功',
  submit: () => { },
  // cancel: () => {},
};
export default Dialog;