import React, { Component } from 'react';
import { addClass, isValue, isNumber, isTel, isEmail, isWord } from '../Utils';

class Input extends Component {
  constructor(props) {
    super(props);
    this.state = {
      value: props.value,
      showRequired: false,
      fileName: props.placeholder,
      classPlace: 'please-fill',
      classRequire: 'infomation-hide'
    }
    if (isValue(props.value)) {
      this.state.classPlace = 'input-name';
      this.state.fileName = props.fileName || props.placeholder;
    }
    this.required = false;
  }

  componentWillReceiveProps(nextProps) {
    this.setState({
      value: nextProps.value
    });
  }

  focus() {
    this.setState({ classPlace: 'input-name', fileName: this.props.fileName || this.props.placeholder });
    this.props.onFocus && this.props.onFocus();
  }
  blur() {
    if (!isValue(this.state.value)) {
      this.required = false;
      this.setState({ classPlace: 'please-fill', classRequire: 'infomation-hide', fileName: this.props.placeholder });
    }
    this.props.onBlur && this.props.onBlur();
  }
  change(val) {
    const { onChange, type, onInput } = this.props;

    const value = val.target.value;

    this.format(value);
    if (type === 'password') {
      onChange && onChange(this.password);
      onInput && onInput(this.password);
      return;
    }
    onChange && onChange(this.state.value);
    onInput && onInput(this.password);

  }

  getRequired() {
    return this.required;
  }

  format(value) {

    const { type, sex, maxLength, minLength, maxNumber, minNumber, isFixed } = this.props;

    if (type === 'text') {
      if (maxLength && value.length > maxLength) {
        return
      } else if (minLength && value.length < minLength) {
        this.state.value = value;
        this.setState({ value, classRequire: 'infomation-show' });
        this.required = false;
        return;
      }
      this.required = true;
      this.state.value = value;
      this.setState({ value, classRequire: 'infomation-hide' });
      return;
    }

    if (type === 'password') {
      if (/^♀*♂*\w*$/.test(value)) {
        const rep = sex === 'woman' ? '♀' : '♂';
        if (isValue(this.password)) { // 如果password不存在，则为第一次出现
          if ((value.length - this.password.length) > 0) {
            this.password += value.substring(this.password.length);
            value = rep.repeat(value.length);
          } else {
            this.password = this.password.substring(0, value.length);
            value = rep.repeat(value.length);
          }
        } else {
          this.password = value;
          value = rep;
        }
        if (maxLength && value.length > maxLength) {
          return
        } else if (minLength && value.length < minLength) {
          this.state.value = value;
          this.setState({ value, classRequire: 'infomation-show' });
          this.required = false;
          return;
        }
        this.state.value = value;
        this.setState({ value, classRequire: 'infomation-hide' });
        this.required = true;
        return;
      } else {
        return;
      }
    }

    if (type === 'number') {
      if (isNumber(value)) {
        if ((isValue(maxNumber) && Number(value) > maxNumber) || (isValue(minNumber) && Number(value) < minNumber)) {
          return
        }
        this.required = true;
        this.state.value = value;
        this.setState({ value, classRequire: 'infomation-hide' });
        return;
      }
      return;
    }

    if (type === 'word') {
      if (isWord(value)) {
        this.required = true;
        this.state.value = value;
        this.setState({ value, classRequire: 'infomation-hide' });
        return;
      }
      return;
    }


    if (type === 'email' && isEmail(value)) {
      this.required = true;
      this.state.value = value;
      this.setState({ value, classRequire: 'infomation-hide' });
      return;
    }

    if (type === 'tel' && isTel(value)) {
      this.required = true;
      this.state.value = value;
      this.setState({ value, classRequire: 'infomation-hide' });
      return;
    }
    this.required = false;
    this.state.value = value;
    this.setState({ value, classRequire: 'infomation-show' });
  }

  render() {

    const { className, style, placeholder, requireText, require, disabled, showName } = this.props;

    const { value, showRequired, classPlace, classRequire, fileName } = this.state;
    return (
      <div className={addClass('input-wrap')}>
        {showName ?
          <div
            className={`placeholder ${classPlace}`}
            onClick={() => { this.input.focus(); }}
          >{fileName}</div> : <div>
            {
              value ? null :
                <div className="placeholder please-fill" onClick={() => { this.input.focus(); }}>{placeholder}</div>
            }
          </div>
        }
        <input
          disabled={disabled}
          className={className}
          style={style}
          type="text"
          value={this.state.value}
          onFocus={this.focus.bind(this)}
          onBlur={this.blur.bind(this)}
          onChange={this.change.bind(this)}
          onClick={() => { this.props.onClick && this.props.onClick(); }}
          ref={c => this.input = c}
        />
        {
          require ? <div className={`infomation ${classRequire}`}>{requireText}</div> : null // 是否显示校验信息
        }
      </div>
    );
  }
}
Input.propTypes = {
  type: React.PropTypes.string,
  value: React.PropTypes.oneOfType([
    React.PropTypes.string,
    React.PropTypes.number
  ]),
  disabled: React.PropTypes.bool,
  className: React.PropTypes.string,
  require: React.PropTypes.bool,
  showName: React.PropTypes.bool,
  requireText: React.PropTypes.string,
  sex: React.PropTypes.string,
  style: React.PropTypes.object,
  placeholder: React.PropTypes.string,
  fileName: React.PropTypes.string,
  maxNumber: React.PropTypes.number,
  minNumber: React.PropTypes.number,
  maxLength: React.PropTypes.number,
  minLength: React.PropTypes.number,
  onChange: React.PropTypes.func,
  onInput: React.PropTypes.func,
  onblur: React.PropTypes.func,
  onFocus: React.PropTypes.func,
  onClick: React.PropTypes.func,
};
Input.defaultProps = {
  type: 'text',
  value: '',
  disabled: false,
  showName: false,
  fileName: '用户名',
  className: '',
  style: {},
  sex: 'man',
  require: false,
  requireText: '输入格式不正确',
  placeholder: '请输入内容',
  maxNumber: '',
  minNumber: '',
  maxLength: '',
  minLength: '',
  onChange: () => { },
  onInput: () => { },
  onblur: () => { },
  onFocus: () => { },
  onClick: () => { },
};
export default Input;