import React, { PropTypes, Component } from 'react';

import RadioItem from './RadioItem.jsx';

require('../Checkbox/style.less');

export default class Radio extends Component {

  constructor(props) {
    super(props);
    this.state = {
      value: props.value || []
    };
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.value !== this.state.value) {
      this.setState({ value: nextProps.value });
    }
  }

  onSelect(key) {
    this.setState({ value: key });
    this.props.onChange(key);
  }

  getValue() {
    return this.state.value;
  }

  render() {
    const { options, disabled, className, lineHeight } = this.props;
    const { value } = this.state;
    return (
      <div className={`cg-checkbox ${className}`}>
        {
          Object.keys(options).map((key, idx) => {
            return (<RadioItem
              className={'checkbox-item'}
              style={{ height: lineHeight }}
              key={idx}
              checked={value == key}
              onChange={this.onSelect.bind(this, key)}
              text={options[key]}
              disabled={disabled}
            />);
          })
        }
      </div>
    );
  }
}

Radio.propTypes = {
  options: PropTypes.objectOf(PropTypes.any),
  value: PropTypes.string,
  onChange: PropTypes.func,
  disabled: PropTypes.bool,
  name: PropTypes.string,
  className: PropTypes.string,
  lineHeight: PropTypes.string
}

Radio.defaultProps = {
  options: {},
  value: null,
  onChange() { },
  disabled: false,
  className: '',
  lineHeight: '30px'
};

