import React, { Component } from 'react';
import { addClass, isValue, isNumber, isTel, isEmail } from '../Utils';

class Textarea extends Component {
  constructor(props) {
    super(props);
    this.state = {
      value: props.value,
      fileName: props.placeholder,
      classPlace: 'please-fill'
    }
    if (isValue(props.value)) {
      this.state.classPlace = 'textarea-name';
      this.state.fileName = props.fileName || props.placeholder;
    }
  }

  focus() {
    this.setState({ classPlace: 'textarea-name', fileName: this.props.fileName || this.props.placeholder });
    this.props.onFocus && this.props.onFocus();
  }
  blur() {
    if (!isValue(this.state.value)) {
      this.setState({ classPlace: 'please-fill', fileName: this.props.placeholder });
    }
    this.props.onBlur && this.props.onBlur();
  }
  change(val) {
    const { onChange, type, onInput } = this.props;
    const value = val.target.value;
    this.format(value);
    onChange && onChange(this.state.value);
    onInput && onInput(this.password);

  }

  format(value) {
    const { maxLength } = this.props;
    if (isValue(maxLength) && value.length > maxLength) {
      return;
    }
    this.state.value = value;
    this.setState({ value });
  }

  render() {

    const { className, style, placeholder } = this.props;

    const { value, classPlace, fileName } = this.state;

    return (
      <div className={addClass('textarea-wrap')}>
        <div
          className={`placeholder ${classPlace}`}
          onMouseDown={(e) => { e.nativeEvent.stopImmediatePropagation(); e.stopPropagation(); e.preventDefault(); this.textarea.focus() }}
        >{fileName}</div>
        <textarea
          ref={c => this.textarea = c}
          value={this.state.value}
          style={style}
          className={className}
          onFocus={this.focus.bind(this)}
          onBlur={this.blur.bind(this)}
          onChange={this.change.bind(this)}
          onClick={() => { this.props.onClick && this.props.onClick(); }}
        >
        </textarea>
      </div>
    );
  }
}

Textarea.propTypes = {
  value: React.PropTypes.string,
  className: React.PropTypes.string,
  style: React.PropTypes.object,
  placeholder: React.PropTypes.string,
  fileName: React.PropTypes.string,
  maxLength: React.PropTypes.number,
  onChange: React.PropTypes.func,
  onblur: React.PropTypes.func,
  onFocus: React.PropTypes.func,
  onClick: React.PropTypes.func,
};
Textarea.defaultProps = {
  value: '',
  fileName: '备注',
  className: '',
  maxLength: 500,
  style: {},
  placeholder: '请输入内容',
  onChange: () => { },
  onblur: () => { },
  onFocus: () => { },
  onClick: () => { },
};
export default Textarea;